# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/event_contracts/v1/event_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/event_contracts/v1/event_contracts_v1.proto\x12\"strmprivacy.api.event_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xe8\x02\n\x19ListEventContractsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12M\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01\x12?\n\nschema_ref\x18\x06 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01\"a\n\x1aListEventContractsResponse\x12\x43\n\x0f\x65vent_contracts\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\"m\n\x17GetEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12:\n\x03ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRef\"u\n\x18GetEventContractResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x8c\x01\n\x1a\x43reateEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x42\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x12\n\nproject_id\x18\x03 \x01(\t\"x\n\x1b\x43reateEventContractResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\xe3\x01\n\x1aUpdateEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12G\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractB\x03\xe0\x41\x02\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02\"x\n\x1bUpdateEventContractResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\x9f\x01\n\x1c\x41\x63tivateEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12N\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x1f\n\x1d\x41\x63tivateEventContractResponse\"\x9d\x01\n\x1a\x44\x65leteEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12N\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x1d\n\x1b\x44\x65leteEventContractResponse\"\x9e\x01\n\x1b\x41rchiveEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12N\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1c\x41rchiveEventContractResponse\"\x90\x01\n\x1bValidateMaskedFieldsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12@\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFields\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x89\x03\n\x1cValidateMaskedFieldsResponse\x12V\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x46.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error\x1a\x90\x02\n\x05\x45rror\x12I\n\x12\x65vent_contract_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRef\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x61\n\x06\x65rrors\x18\x03 \x03(\x0b\x32Q.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error.FieldError\x1aH\n\nFieldError\x12\x15\n\rfield_pattern\x18\x01 \x01(\t\x12\x12\n\nfield_type\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"^\n GetEventContractAndSchemaRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRef\"\xb2\x01\n!GetEventContractAndSchemaResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x33\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x14\n\x0c\x63onfluent_id\x18\x03 \x01(\x05\x32\x8a\x0b\n\x15\x45ventContractsService\x12\x93\x01\n\x12ListEventContracts\x12=.strmprivacy.api.event_contracts.v1.ListEventContractsRequest\x1a>.strmprivacy.api.event_contracts.v1.ListEventContractsResponse\x12\x8d\x01\n\x10GetEventContract\x12;.strmprivacy.api.event_contracts.v1.GetEventContractRequest\x1a<.strmprivacy.api.event_contracts.v1.GetEventContractResponse\x12\x96\x01\n\x13\x43reateEventContract\x12>.strmprivacy.api.event_contracts.v1.CreateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.CreateEventContractResponse\x12\x96\x01\n\x13UpdateEventContract\x12>.strmprivacy.api.event_contracts.v1.UpdateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.UpdateEventContractResponse\x12\x9c\x01\n\x15\x41\x63tivateEventContract\x12@.strmprivacy.api.event_contracts.v1.ActivateEventContractRequest\x1a\x41.strmprivacy.api.event_contracts.v1.ActivateEventContractResponse\x12\x96\x01\n\x13\x44\x65leteEventContract\x12>.strmprivacy.api.event_contracts.v1.DeleteEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.DeleteEventContractResponse\x12\x99\x01\n\x14\x41rchiveEventContract\x12?.strmprivacy.api.event_contracts.v1.ArchiveEventContractRequest\x1a@.strmprivacy.api.event_contracts.v1.ArchiveEventContractResponse\x12\x99\x01\n\x14ValidateMaskedFields\x12?.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsRequest\x1a@.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse\x12\xa8\x01\n\x19GetEventContractAndSchema\x12\x44.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaRequest\x1a\x45.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaResponseB~\n%io.strmprivacy.api.event_contracts.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contractsb\x06proto3')



_LISTEVENTCONTRACTSREQUEST = DESCRIPTOR.message_types_by_name['ListEventContractsRequest']
_LISTEVENTCONTRACTSRESPONSE = DESCRIPTOR.message_types_by_name['ListEventContractsResponse']
_GETEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['GetEventContractRequest']
_GETEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['GetEventContractResponse']
_CREATEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['CreateEventContractRequest']
_CREATEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['CreateEventContractResponse']
_UPDATEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['UpdateEventContractRequest']
_UPDATEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEventContractResponse']
_ACTIVATEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ActivateEventContractRequest']
_ACTIVATEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ActivateEventContractResponse']
_DELETEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['DeleteEventContractRequest']
_DELETEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEventContractResponse']
_ARCHIVEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ArchiveEventContractRequest']
_ARCHIVEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ArchiveEventContractResponse']
_VALIDATEMASKEDFIELDSREQUEST = DESCRIPTOR.message_types_by_name['ValidateMaskedFieldsRequest']
_VALIDATEMASKEDFIELDSRESPONSE = DESCRIPTOR.message_types_by_name['ValidateMaskedFieldsResponse']
_VALIDATEMASKEDFIELDSRESPONSE_ERROR = _VALIDATEMASKEDFIELDSRESPONSE.nested_types_by_name['Error']
_VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR = _VALIDATEMASKEDFIELDSRESPONSE_ERROR.nested_types_by_name['FieldError']
_GETEVENTCONTRACTANDSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['GetEventContractAndSchemaRequest']
_GETEVENTCONTRACTANDSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['GetEventContractAndSchemaResponse']
ListEventContractsRequest = _reflection.GeneratedProtocolMessageType('ListEventContractsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTCONTRACTSREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ListEventContractsRequest)
  })
_sym_db.RegisterMessage(ListEventContractsRequest)

ListEventContractsResponse = _reflection.GeneratedProtocolMessageType('ListEventContractsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTCONTRACTSRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ListEventContractsResponse)
  })
_sym_db.RegisterMessage(ListEventContractsResponse)

GetEventContractRequest = _reflection.GeneratedProtocolMessageType('GetEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractRequest)
  })
_sym_db.RegisterMessage(GetEventContractRequest)

GetEventContractResponse = _reflection.GeneratedProtocolMessageType('GetEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractResponse)
  })
_sym_db.RegisterMessage(GetEventContractResponse)

CreateEventContractRequest = _reflection.GeneratedProtocolMessageType('CreateEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.CreateEventContractRequest)
  })
_sym_db.RegisterMessage(CreateEventContractRequest)

CreateEventContractResponse = _reflection.GeneratedProtocolMessageType('CreateEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.CreateEventContractResponse)
  })
_sym_db.RegisterMessage(CreateEventContractResponse)

UpdateEventContractRequest = _reflection.GeneratedProtocolMessageType('UpdateEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.UpdateEventContractRequest)
  })
_sym_db.RegisterMessage(UpdateEventContractRequest)

UpdateEventContractResponse = _reflection.GeneratedProtocolMessageType('UpdateEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.UpdateEventContractResponse)
  })
_sym_db.RegisterMessage(UpdateEventContractResponse)

ActivateEventContractRequest = _reflection.GeneratedProtocolMessageType('ActivateEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ActivateEventContractRequest)
  })
_sym_db.RegisterMessage(ActivateEventContractRequest)

ActivateEventContractResponse = _reflection.GeneratedProtocolMessageType('ActivateEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ActivateEventContractResponse)
  })
_sym_db.RegisterMessage(ActivateEventContractResponse)

DeleteEventContractRequest = _reflection.GeneratedProtocolMessageType('DeleteEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.DeleteEventContractRequest)
  })
_sym_db.RegisterMessage(DeleteEventContractRequest)

DeleteEventContractResponse = _reflection.GeneratedProtocolMessageType('DeleteEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.DeleteEventContractResponse)
  })
_sym_db.RegisterMessage(DeleteEventContractResponse)

ArchiveEventContractRequest = _reflection.GeneratedProtocolMessageType('ArchiveEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ArchiveEventContractRequest)
  })
_sym_db.RegisterMessage(ArchiveEventContractRequest)

ArchiveEventContractResponse = _reflection.GeneratedProtocolMessageType('ArchiveEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ArchiveEventContractResponse)
  })
_sym_db.RegisterMessage(ArchiveEventContractResponse)

ValidateMaskedFieldsRequest = _reflection.GeneratedProtocolMessageType('ValidateMaskedFieldsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEMASKEDFIELDSREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsRequest)
  })
_sym_db.RegisterMessage(ValidateMaskedFieldsRequest)

ValidateMaskedFieldsResponse = _reflection.GeneratedProtocolMessageType('ValidateMaskedFieldsResponse', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {

    'FieldError' : _reflection.GeneratedProtocolMessageType('FieldError', (_message.Message,), {
      'DESCRIPTOR' : _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR,
      '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
      # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error.FieldError)
      })
    ,
    'DESCRIPTOR' : _VALIDATEMASKEDFIELDSRESPONSE_ERROR,
    '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error)
    })
  ,
  'DESCRIPTOR' : _VALIDATEMASKEDFIELDSRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse)
  })
_sym_db.RegisterMessage(ValidateMaskedFieldsResponse)
_sym_db.RegisterMessage(ValidateMaskedFieldsResponse.Error)
_sym_db.RegisterMessage(ValidateMaskedFieldsResponse.Error.FieldError)

GetEventContractAndSchemaRequest = _reflection.GeneratedProtocolMessageType('GetEventContractAndSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTANDSCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaRequest)
  })
_sym_db.RegisterMessage(GetEventContractAndSchemaRequest)

GetEventContractAndSchemaResponse = _reflection.GeneratedProtocolMessageType('GetEventContractAndSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTANDSCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaResponse)
  })
_sym_db.RegisterMessage(GetEventContractAndSchemaResponse)

_EVENTCONTRACTSSERVICE = DESCRIPTOR.services_by_name['EventContractsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.event_contracts.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contracts'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _LISTEVENTCONTRACTSREQUEST._serialized_start=214
  _LISTEVENTCONTRACTSREQUEST._serialized_end=574
  _LISTEVENTCONTRACTSRESPONSE._serialized_start=576
  _LISTEVENTCONTRACTSRESPONSE._serialized_end=673
  _GETEVENTCONTRACTREQUEST._serialized_start=675
  _GETEVENTCONTRACTREQUEST._serialized_end=784
  _GETEVENTCONTRACTRESPONSE._serialized_start=786
  _GETEVENTCONTRACTRESPONSE._serialized_end=903
  _CREATEEVENTCONTRACTREQUEST._serialized_start=906
  _CREATEEVENTCONTRACTREQUEST._serialized_end=1046
  _CREATEEVENTCONTRACTRESPONSE._serialized_start=1048
  _CREATEEVENTCONTRACTRESPONSE._serialized_end=1168
  _UPDATEEVENTCONTRACTREQUEST._serialized_start=1171
  _UPDATEEVENTCONTRACTREQUEST._serialized_end=1398
  _UPDATEEVENTCONTRACTRESPONSE._serialized_start=1400
  _UPDATEEVENTCONTRACTRESPONSE._serialized_end=1520
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_start=1523
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_end=1682
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_start=1684
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_end=1715
  _DELETEEVENTCONTRACTREQUEST._serialized_start=1718
  _DELETEEVENTCONTRACTREQUEST._serialized_end=1875
  _DELETEEVENTCONTRACTRESPONSE._serialized_start=1877
  _DELETEEVENTCONTRACTRESPONSE._serialized_end=1906
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_start=1909
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_end=2067
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_start=2069
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_end=2099
  _VALIDATEMASKEDFIELDSREQUEST._serialized_start=2102
  _VALIDATEMASKEDFIELDSREQUEST._serialized_end=2246
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_start=2249
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_end=2642
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_start=2370
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_end=2642
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=2570
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=2642
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_start=2644
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_end=2738
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_start=2741
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_end=2919
  _EVENTCONTRACTSSERVICE._serialized_start=2922
  _EVENTCONTRACTSSERVICE._serialized_end=4340
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_connectors/v1/data_connectors_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/data_connectors/v1/data_connectors_v1.proto\x12\"strmprivacy.api.data_connectors.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"|\n\x19ListDataConnectorsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08\x12\x17\n\nproject_id\x18\x04 \x01(\tB\x03\xe0\x41\x02\"a\n\x1aListDataConnectorsResponse\x12\x43\n\x0f\x64\x61ta_connectors\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.DataConnector\"p\n\x1a\x44\x65leteDataConnectorRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08\"\x1d\n\x1b\x44\x65leteDataConnectorResponse\"e\n\x1a\x43reateDataConnectorRequest\x12G\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorB\x03\xe0\x41\x02\"a\n\x1b\x43reateDataConnectorResponse\x12\x42\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnector\"\x8a\x01\n\x17GetDataConnectorRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08\"^\n\x18GetDataConnectorResponse\x12\x42\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnector2\xef\x04\n\x15\x44\x61taConnectorsService\x12\x93\x01\n\x12ListDataConnectors\x12=.strmprivacy.api.data_connectors.v1.ListDataConnectorsRequest\x1a>.strmprivacy.api.data_connectors.v1.ListDataConnectorsResponse\x12\x8d\x01\n\x10GetDataConnector\x12;.strmprivacy.api.data_connectors.v1.GetDataConnectorRequest\x1a<.strmprivacy.api.data_connectors.v1.GetDataConnectorResponse\x12\x96\x01\n\x13\x44\x65leteDataConnector\x12>.strmprivacy.api.data_connectors.v1.DeleteDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.DeleteDataConnectorResponse\x12\x96\x01\n\x13\x43reateDataConnector\x12>.strmprivacy.api.data_connectors.v1.CreateDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.CreateDataConnectorResponseB~\n%io.strmprivacy.api.data_connectors.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectorsb\x06proto3')



_LISTDATACONNECTORSREQUEST = DESCRIPTOR.message_types_by_name['ListDataConnectorsRequest']
_LISTDATACONNECTORSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataConnectorsResponse']
_DELETEDATACONNECTORREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataConnectorRequest']
_DELETEDATACONNECTORRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataConnectorResponse']
_CREATEDATACONNECTORREQUEST = DESCRIPTOR.message_types_by_name['CreateDataConnectorRequest']
_CREATEDATACONNECTORRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataConnectorResponse']
_GETDATACONNECTORREQUEST = DESCRIPTOR.message_types_by_name['GetDataConnectorRequest']
_GETDATACONNECTORRESPONSE = DESCRIPTOR.message_types_by_name['GetDataConnectorResponse']
ListDataConnectorsRequest = _reflection.GeneratedProtocolMessageType('ListDataConnectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONNECTORSREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.ListDataConnectorsRequest)
  })
_sym_db.RegisterMessage(ListDataConnectorsRequest)

ListDataConnectorsResponse = _reflection.GeneratedProtocolMessageType('ListDataConnectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONNECTORSRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.ListDataConnectorsResponse)
  })
_sym_db.RegisterMessage(ListDataConnectorsResponse)

DeleteDataConnectorRequest = _reflection.GeneratedProtocolMessageType('DeleteDataConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONNECTORREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.DeleteDataConnectorRequest)
  })
_sym_db.RegisterMessage(DeleteDataConnectorRequest)

DeleteDataConnectorResponse = _reflection.GeneratedProtocolMessageType('DeleteDataConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONNECTORRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.DeleteDataConnectorResponse)
  })
_sym_db.RegisterMessage(DeleteDataConnectorResponse)

CreateDataConnectorRequest = _reflection.GeneratedProtocolMessageType('CreateDataConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONNECTORREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.CreateDataConnectorRequest)
  })
_sym_db.RegisterMessage(CreateDataConnectorRequest)

CreateDataConnectorResponse = _reflection.GeneratedProtocolMessageType('CreateDataConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONNECTORRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.CreateDataConnectorResponse)
  })
_sym_db.RegisterMessage(CreateDataConnectorResponse)

GetDataConnectorRequest = _reflection.GeneratedProtocolMessageType('GetDataConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONNECTORREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.GetDataConnectorRequest)
  })
_sym_db.RegisterMessage(GetDataConnectorRequest)

GetDataConnectorResponse = _reflection.GeneratedProtocolMessageType('GetDataConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONNECTORRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.GetDataConnectorResponse)
  })
_sym_db.RegisterMessage(GetDataConnectorResponse)

_DATACONNECTORSSERVICE = DESCRIPTOR.services_by_name['DataConnectorsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.data_connectors.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectors'
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._options = None
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._serialized_options = b'\340A\002'
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTDATACONNECTORSREQUEST._serialized_start=179
  _LISTDATACONNECTORSREQUEST._serialized_end=303
  _LISTDATACONNECTORSRESPONSE._serialized_start=305
  _LISTDATACONNECTORSRESPONSE._serialized_end=402
  _DELETEDATACONNECTORREQUEST._serialized_start=404
  _DELETEDATACONNECTORREQUEST._serialized_end=516
  _DELETEDATACONNECTORRESPONSE._serialized_start=518
  _DELETEDATACONNECTORRESPONSE._serialized_end=547
  _CREATEDATACONNECTORREQUEST._serialized_start=549
  _CREATEDATACONNECTORREQUEST._serialized_end=650
  _CREATEDATACONNECTORRESPONSE._serialized_start=652
  _CREATEDATACONNECTORRESPONSE._serialized_end=749
  _GETDATACONNECTORREQUEST._serialized_start=752
  _GETDATACONNECTORREQUEST._serialized_end=890
  _GETDATACONNECTORRESPONSE._serialized_start=892
  _GETDATACONNECTORRESPONSE._serialized_end=986
  _DATACONNECTORSSERVICE._serialized_start=989
  _DATACONNECTORSSERVICE._serialized_end=1612
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/agents/v1/batch_exporters_agent_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8strmprivacy/api/agents/v1/batch_exporters_agent_v1.proto\x12\x19strmprivacy.api.agents.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"!\n\x1fGetDesiredBatchExportersRequest\"i\n GetDesiredBatchExportersResponse\x12\x45\n\texporters\x18\x01 \x03(\x0b\x32\x32.strmprivacy.api.entities.v1.ExtendedBatchExporter2\xb2\x01\n\x1a\x42\x61tchExportersAgentService\x12\x93\x01\n\x18GetDesiredBatchExporters\x12:.strmprivacy.api.agents.v1.GetDesiredBatchExportersRequest\x1a;.strmprivacy.api.agents.v1.GetDesiredBatchExportersResponseBc\n\x1cio.strmprivacy.api.agents.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agentsb\x06proto3')



_GETDESIREDBATCHEXPORTERSREQUEST = DESCRIPTOR.message_types_by_name['GetDesiredBatchExportersRequest']
_GETDESIREDBATCHEXPORTERSRESPONSE = DESCRIPTOR.message_types_by_name['GetDesiredBatchExportersResponse']
GetDesiredBatchExportersRequest = _reflection.GeneratedProtocolMessageType('GetDesiredBatchExportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDBATCHEXPORTERSREQUEST,
  '__module__' : 'strmprivacy.api.agents.v1.batch_exporters_agent_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.agents.v1.GetDesiredBatchExportersRequest)
  })
_sym_db.RegisterMessage(GetDesiredBatchExportersRequest)

GetDesiredBatchExportersResponse = _reflection.GeneratedProtocolMessageType('GetDesiredBatchExportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDBATCHEXPORTERSRESPONSE,
  '__module__' : 'strmprivacy.api.agents.v1.batch_exporters_agent_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.agents.v1.GetDesiredBatchExportersResponse)
  })
_sym_db.RegisterMessage(GetDesiredBatchExportersResponse)

_BATCHEXPORTERSAGENTSERVICE = DESCRIPTOR.services_by_name['BatchExportersAgentService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.agents.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agents'
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_start=134
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_end=167
  _GETDESIREDBATCHEXPORTERSRESPONSE._serialized_start=169
  _GETDESIREDBATCHEXPORTERSRESPONSE._serialized_end=274
  _BATCHEXPORTERSAGENTSERVICE._serialized_start=277
  _BATCHEXPORTERSAGENTSERVICE._serialized_end=455
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installed_components_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>strmprivacy/api/installations/v1/installed_components_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"\x98\x02\n$UpdateInstalledComponentStateRequest\x12U\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\x12\x18\n\x0binstance_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x61\n\x19installed_component_state\x18\x03 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateB\x03\xe0\x41\x02\x12\x1c\n\x0finstallation_id\x18\x04 \x01(\tB\x03\xe0\x41\x02\"\'\n%UpdateInstalledComponentStateResponse\"\x9d\x01\n\x1cGetInstalledComponentRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12_\n\x18installed_component_type\x18\x02 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\"r\n\x1dGetInstalledComponentResponse\x12Q\n\x13installed_component\x18\x01 \x01(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponent\">\n\x1eListInstalledComponentsRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"u\n\x1fListInstalledComponentsResponse\x12R\n\x14installed_components\x18\x01 \x03(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponent\"K\n+ListInstalledComponentsCurrentStatesRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8f\x01\n,ListInstalledComponentsCurrentStatesResponse\x12_\n\x14installed_components\x18\x01 \x03(\x0b\x32\x41.strmprivacy.api.installations.v1.InstalledComponentsCurrentState2\xd3\x05\n\x1aInstalledComponentsService\x12\xb0\x01\n\x1dUpdateInstalledComponentState\x12\x46.strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest\x1aG.strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse\x12\x98\x01\n\x15GetInstalledComponent\x12>.strmprivacy.api.installations.v1.GetInstalledComponentRequest\x1a?.strmprivacy.api.installations.v1.GetInstalledComponentResponse\x12\x9e\x01\n\x17ListInstalledComponents\x12@.strmprivacy.api.installations.v1.ListInstalledComponentsRequest\x1a\x41.strmprivacy.api.installations.v1.ListInstalledComponentsResponse\x12\xc5\x01\n$ListInstalledComponentsCurrentStates\x12M.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest\x1aN.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')



_UPDATEINSTALLEDCOMPONENTSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateInstalledComponentStateRequest']
_UPDATEINSTALLEDCOMPONENTSTATERESPONSE = DESCRIPTOR.message_types_by_name['UpdateInstalledComponentStateResponse']
_GETINSTALLEDCOMPONENTREQUEST = DESCRIPTOR.message_types_by_name['GetInstalledComponentRequest']
_GETINSTALLEDCOMPONENTRESPONSE = DESCRIPTOR.message_types_by_name['GetInstalledComponentResponse']
_LISTINSTALLEDCOMPONENTSREQUEST = DESCRIPTOR.message_types_by_name['ListInstalledComponentsRequest']
_LISTINSTALLEDCOMPONENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListInstalledComponentsResponse']
_LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST = DESCRIPTOR.message_types_by_name['ListInstalledComponentsCurrentStatesRequest']
_LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE = DESCRIPTOR.message_types_by_name['ListInstalledComponentsCurrentStatesResponse']
UpdateInstalledComponentStateRequest = _reflection.GeneratedProtocolMessageType('UpdateInstalledComponentStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTALLEDCOMPONENTSTATEREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest)
  })
_sym_db.RegisterMessage(UpdateInstalledComponentStateRequest)

UpdateInstalledComponentStateResponse = _reflection.GeneratedProtocolMessageType('UpdateInstalledComponentStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTALLEDCOMPONENTSTATERESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse)
  })
_sym_db.RegisterMessage(UpdateInstalledComponentStateResponse)

GetInstalledComponentRequest = _reflection.GeneratedProtocolMessageType('GetInstalledComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLEDCOMPONENTREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstalledComponentRequest)
  })
_sym_db.RegisterMessage(GetInstalledComponentRequest)

GetInstalledComponentResponse = _reflection.GeneratedProtocolMessageType('GetInstalledComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLEDCOMPONENTRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstalledComponentResponse)
  })
_sym_db.RegisterMessage(GetInstalledComponentResponse)

ListInstalledComponentsRequest = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsRequest)
  })
_sym_db.RegisterMessage(ListInstalledComponentsRequest)

ListInstalledComponentsResponse = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsResponse)
  })
_sym_db.RegisterMessage(ListInstalledComponentsResponse)

ListInstalledComponentsCurrentStatesRequest = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsCurrentStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest)
  })
_sym_db.RegisterMessage(ListInstalledComponentsCurrentStatesRequest)

ListInstalledComponentsCurrentStatesResponse = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsCurrentStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponse)
  })
_sym_db.RegisterMessage(ListInstalledComponentsCurrentStatesResponse)

_INSTALLEDCOMPONENTSSERVICE = DESCRIPTOR.services_by_name['InstalledComponentsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_start=186
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_end=466
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_start=468
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_end=507
  _GETINSTALLEDCOMPONENTREQUEST._serialized_start=510
  _GETINSTALLEDCOMPONENTREQUEST._serialized_end=667
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_start=669
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_end=783
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_start=785
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_end=847
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_start=849
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_end=966
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_start=968
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_end=1043
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_start=1046
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_end=1189
  _INSTALLEDCOMPONENTSSERVICE._serialized_start=1192
  _INSTALLEDCOMPONENTSSERVICE._serialized_end=1915
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_users/v1/kafka_users_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/kafka_users/v1/kafka_users_v1.proto\x12\x1estrmprivacy.api.kafka_users.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"X\n\x15ListKafkaUsersRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x03\xe0\x41\x02\"U\n\x16ListKafkaUsersResponse\x12;\n\x0bkafka_users\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"U\n\x16\x44\x65leteKafkaUserRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x03\xe0\x41\x02\"\x19\n\x17\x44\x65leteKafkaUserResponse\"T\n\x16\x43reateKafkaUserRequest\x12:\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"U\n\x17\x43reateKafkaUserResponse\x12:\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"R\n\x13GetKafkaUserRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x03\xe0\x41\x02\"R\n\x14GetKafkaUserResponse\x12:\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser2\x99\x04\n\x11KafkaUsersService\x12\x7f\n\x0eListKafkaUsers\x12\x35.strmprivacy.api.kafka_users.v1.ListKafkaUsersRequest\x1a\x36.strmprivacy.api.kafka_users.v1.ListKafkaUsersResponse\x12y\n\x0cGetKafkaUser\x12\x33.strmprivacy.api.kafka_users.v1.GetKafkaUserRequest\x1a\x34.strmprivacy.api.kafka_users.v1.GetKafkaUserResponse\x12\x82\x01\n\x0f\x44\x65leteKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.DeleteKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.DeleteKafkaUserResponse\x12\x82\x01\n\x0f\x43reateKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.CreateKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.CreateKafkaUserResponseBr\n!io.strmprivacy.api.kafka_users.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_usersb\x06proto3')



_LISTKAFKAUSERSREQUEST = DESCRIPTOR.message_types_by_name['ListKafkaUsersRequest']
_LISTKAFKAUSERSRESPONSE = DESCRIPTOR.message_types_by_name['ListKafkaUsersResponse']
_DELETEKAFKAUSERREQUEST = DESCRIPTOR.message_types_by_name['DeleteKafkaUserRequest']
_DELETEKAFKAUSERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteKafkaUserResponse']
_CREATEKAFKAUSERREQUEST = DESCRIPTOR.message_types_by_name['CreateKafkaUserRequest']
_CREATEKAFKAUSERRESPONSE = DESCRIPTOR.message_types_by_name['CreateKafkaUserResponse']
_GETKAFKAUSERREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaUserRequest']
_GETKAFKAUSERRESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaUserResponse']
ListKafkaUsersRequest = _reflection.GeneratedProtocolMessageType('ListKafkaUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKAUSERSREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.ListKafkaUsersRequest)
  })
_sym_db.RegisterMessage(ListKafkaUsersRequest)

ListKafkaUsersResponse = _reflection.GeneratedProtocolMessageType('ListKafkaUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKAUSERSRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.ListKafkaUsersResponse)
  })
_sym_db.RegisterMessage(ListKafkaUsersResponse)

DeleteKafkaUserRequest = _reflection.GeneratedProtocolMessageType('DeleteKafkaUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKAUSERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.DeleteKafkaUserRequest)
  })
_sym_db.RegisterMessage(DeleteKafkaUserRequest)

DeleteKafkaUserResponse = _reflection.GeneratedProtocolMessageType('DeleteKafkaUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKAUSERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.DeleteKafkaUserResponse)
  })
_sym_db.RegisterMessage(DeleteKafkaUserResponse)

CreateKafkaUserRequest = _reflection.GeneratedProtocolMessageType('CreateKafkaUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKAUSERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.CreateKafkaUserRequest)
  })
_sym_db.RegisterMessage(CreateKafkaUserRequest)

CreateKafkaUserResponse = _reflection.GeneratedProtocolMessageType('CreateKafkaUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKAUSERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.CreateKafkaUserResponse)
  })
_sym_db.RegisterMessage(CreateKafkaUserResponse)

GetKafkaUserRequest = _reflection.GeneratedProtocolMessageType('GetKafkaUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAUSERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.GetKafkaUserRequest)
  })
_sym_db.RegisterMessage(GetKafkaUserRequest)

GetKafkaUserResponse = _reflection.GeneratedProtocolMessageType('GetKafkaUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAUSERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.GetKafkaUserResponse)
  })
_sym_db.RegisterMessage(GetKafkaUserResponse)

_KAFKAUSERSSERVICE = DESCRIPTOR.services_by_name['KafkaUsersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.kafka_users.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_users'
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._options = None
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTKAFKAUSERSREQUEST._serialized_start=167
  _LISTKAFKAUSERSREQUEST._serialized_end=255
  _LISTKAFKAUSERSRESPONSE._serialized_start=257
  _LISTKAFKAUSERSRESPONSE._serialized_end=342
  _DELETEKAFKAUSERREQUEST._serialized_start=344
  _DELETEKAFKAUSERREQUEST._serialized_end=429
  _DELETEKAFKAUSERRESPONSE._serialized_start=431
  _DELETEKAFKAUSERRESPONSE._serialized_end=456
  _CREATEKAFKAUSERREQUEST._serialized_start=458
  _CREATEKAFKAUSERREQUEST._serialized_end=542
  _CREATEKAFKAUSERRESPONSE._serialized_start=544
  _CREATEKAFKAUSERRESPONSE._serialized_end=629
  _GETKAFKAUSERREQUEST._serialized_start=631
  _GETKAFKAUSERREQUEST._serialized_end=713
  _GETKAFKAUSERRESPONSE._serialized_start=715
  _GETKAFKAUSERRESPONSE._serialized_end=797
  _KAFKAUSERSSERVICE._serialized_start=800
  _KAFKAUSERSSERVICE._serialized_end=1337
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto\x12\"strmprivacy.api.batch_exporters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"L\n\x19ListBatchExportersRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"a\n\x1aListBatchExportersResponse\x12\x43\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"]\n\x1a\x44\x65leteBatchExporterRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02\"\x1d\n\x1b\x44\x65leteBatchExporterResponse\"`\n\x1a\x43reateBatchExporterRequest\x12\x42\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"a\n\x1b\x43reateBatchExporterResponse\x12\x42\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"Z\n\x17GetBatchExporterRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02\"^\n\x18GetBatchExporterResponse\x12\x42\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter2\xef\x04\n\x15\x42\x61tchExportersService\x12\x93\x01\n\x12ListBatchExporters\x12=.strmprivacy.api.batch_exporters.v1.ListBatchExportersRequest\x1a>.strmprivacy.api.batch_exporters.v1.ListBatchExportersResponse\x12\x8d\x01\n\x10GetBatchExporter\x12;.strmprivacy.api.batch_exporters.v1.GetBatchExporterRequest\x1a<.strmprivacy.api.batch_exporters.v1.GetBatchExporterResponse\x12\x96\x01\n\x13\x44\x65leteBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterResponse\x12\x96\x01\n\x13\x43reateBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.CreateBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.CreateBatchExporterResponseB~\n%io.strmprivacy.api.batch_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exportersb\x06proto3')



_LISTBATCHEXPORTERSREQUEST = DESCRIPTOR.message_types_by_name['ListBatchExportersRequest']
_LISTBATCHEXPORTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListBatchExportersResponse']
_DELETEBATCHEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteBatchExporterRequest']
_DELETEBATCHEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBatchExporterResponse']
_CREATEBATCHEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['CreateBatchExporterRequest']
_CREATEBATCHEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['CreateBatchExporterResponse']
_GETBATCHEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['GetBatchExporterRequest']
_GETBATCHEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchExporterResponse']
ListBatchExportersRequest = _reflection.GeneratedProtocolMessageType('ListBatchExportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHEXPORTERSREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.ListBatchExportersRequest)
  })
_sym_db.RegisterMessage(ListBatchExportersRequest)

ListBatchExportersResponse = _reflection.GeneratedProtocolMessageType('ListBatchExportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHEXPORTERSRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.ListBatchExportersResponse)
  })
_sym_db.RegisterMessage(ListBatchExportersResponse)

DeleteBatchExporterRequest = _reflection.GeneratedProtocolMessageType('DeleteBatchExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.DeleteBatchExporterRequest)
  })
_sym_db.RegisterMessage(DeleteBatchExporterRequest)

DeleteBatchExporterResponse = _reflection.GeneratedProtocolMessageType('DeleteBatchExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.DeleteBatchExporterResponse)
  })
_sym_db.RegisterMessage(DeleteBatchExporterResponse)

CreateBatchExporterRequest = _reflection.GeneratedProtocolMessageType('CreateBatchExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.CreateBatchExporterRequest)
  })
_sym_db.RegisterMessage(CreateBatchExporterRequest)

CreateBatchExporterResponse = _reflection.GeneratedProtocolMessageType('CreateBatchExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.CreateBatchExporterResponse)
  })
_sym_db.RegisterMessage(CreateBatchExporterResponse)

GetBatchExporterRequest = _reflection.GeneratedProtocolMessageType('GetBatchExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.GetBatchExporterRequest)
  })
_sym_db.RegisterMessage(GetBatchExporterRequest)

GetBatchExporterResponse = _reflection.GeneratedProtocolMessageType('GetBatchExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.GetBatchExporterResponse)
  })
_sym_db.RegisterMessage(GetBatchExporterResponse)

_BATCHEXPORTERSSERVICE = DESCRIPTOR.services_by_name['BatchExportersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.batch_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exporters'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTBATCHEXPORTERSREQUEST._serialized_start=179
  _LISTBATCHEXPORTERSREQUEST._serialized_end=255
  _LISTBATCHEXPORTERSRESPONSE._serialized_start=257
  _LISTBATCHEXPORTERSRESPONSE._serialized_end=354
  _DELETEBATCHEXPORTERREQUEST._serialized_start=356
  _DELETEBATCHEXPORTERREQUEST._serialized_end=449
  _DELETEBATCHEXPORTERRESPONSE._serialized_start=451
  _DELETEBATCHEXPORTERRESPONSE._serialized_end=480
  _CREATEBATCHEXPORTERREQUEST._serialized_start=482
  _CREATEBATCHEXPORTERREQUEST._serialized_end=578
  _CREATEBATCHEXPORTERRESPONSE._serialized_start=580
  _CREATEBATCHEXPORTERRESPONSE._serialized_end=677
  _GETBATCHEXPORTERREQUEST._serialized_start=679
  _GETBATCHEXPORTERREQUEST._serialized_end=769
  _GETBATCHEXPORTERRESPONSE._serialized_start=771
  _GETBATCHEXPORTERRESPONSE._serialized_end=865
  _BATCHEXPORTERSSERVICE._serialized_start=868
  _BATCHEXPORTERSSERVICE._serialized_end=1491
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/sinks/v1/sinks_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/sinks/v1/sinks_v1.proto\x12\x18strmprivacy.api.sinks.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"Z\n\x10ListSinksRequest\x12\x12\n\nbilling_id\x18\x01 \x01(\t\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08:\x02\x18\x01\"M\n\x11ListSinksResponse\x12\x34\n\x05sinks\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.SinkTree:\x02\x18\x01\"b\n\x11\x44\x65leteSinkRequest\x12\x36\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08:\x02\x18\x01\"\x18\n\x12\x44\x65leteSinkResponse:\x02\x18\x01\"j\n\x11\x43reateSinkRequest\x12\x34\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02\x12\x1b\n\x13include_credentials\x18\x02 \x01(\x08:\x02\x18\x01\"I\n\x12\x43reateSinkResponse\x12/\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.Sink:\x02\x18\x01\"|\n\x0eGetSinkRequest\x12\x36\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08:\x02\x18\x01\"O\n\x0fGetSinkResponse\x12\x38\n\tsink_tree\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.SinkTree:\x02\x18\x01\x32\xab\x03\n\x0cSinksService\x12\x64\n\tListSinks\x12*.strmprivacy.api.sinks.v1.ListSinksRequest\x1a+.strmprivacy.api.sinks.v1.ListSinksResponse\x12^\n\x07GetSink\x12(.strmprivacy.api.sinks.v1.GetSinkRequest\x1a).strmprivacy.api.sinks.v1.GetSinkResponse\x12g\n\nDeleteSink\x12+.strmprivacy.api.sinks.v1.DeleteSinkRequest\x1a,.strmprivacy.api.sinks.v1.DeleteSinkResponse\x12g\n\nCreateSink\x12+.strmprivacy.api.sinks.v1.CreateSinkRequest\x1a,.strmprivacy.api.sinks.v1.CreateSinkResponse\x1a\x03\x88\x02\x01\x42`\n\x1bio.strmprivacy.api.sinks.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinksb\x06proto3')



_LISTSINKSREQUEST = DESCRIPTOR.message_types_by_name['ListSinksRequest']
_LISTSINKSRESPONSE = DESCRIPTOR.message_types_by_name['ListSinksResponse']
_DELETESINKREQUEST = DESCRIPTOR.message_types_by_name['DeleteSinkRequest']
_DELETESINKRESPONSE = DESCRIPTOR.message_types_by_name['DeleteSinkResponse']
_CREATESINKREQUEST = DESCRIPTOR.message_types_by_name['CreateSinkRequest']
_CREATESINKRESPONSE = DESCRIPTOR.message_types_by_name['CreateSinkResponse']
_GETSINKREQUEST = DESCRIPTOR.message_types_by_name['GetSinkRequest']
_GETSINKRESPONSE = DESCRIPTOR.message_types_by_name['GetSinkResponse']
ListSinksRequest = _reflection.GeneratedProtocolMessageType('ListSinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.ListSinksRequest)
  })
_sym_db.RegisterMessage(ListSinksRequest)

ListSinksResponse = _reflection.GeneratedProtocolMessageType('ListSinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.ListSinksResponse)
  })
_sym_db.RegisterMessage(ListSinksResponse)

DeleteSinkRequest = _reflection.GeneratedProtocolMessageType('DeleteSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.DeleteSinkRequest)
  })
_sym_db.RegisterMessage(DeleteSinkRequest)

DeleteSinkResponse = _reflection.GeneratedProtocolMessageType('DeleteSinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.DeleteSinkResponse)
  })
_sym_db.RegisterMessage(DeleteSinkResponse)

CreateSinkRequest = _reflection.GeneratedProtocolMessageType('CreateSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESINKREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.CreateSinkRequest)
  })
_sym_db.RegisterMessage(CreateSinkRequest)

CreateSinkResponse = _reflection.GeneratedProtocolMessageType('CreateSinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESINKRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.CreateSinkResponse)
  })
_sym_db.RegisterMessage(CreateSinkResponse)

GetSinkRequest = _reflection.GeneratedProtocolMessageType('GetSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSINKREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.GetSinkRequest)
  })
_sym_db.RegisterMessage(GetSinkRequest)

GetSinkResponse = _reflection.GeneratedProtocolMessageType('GetSinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSINKRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.GetSinkResponse)
  })
_sym_db.RegisterMessage(GetSinkResponse)

_SINKSSERVICE = DESCRIPTOR.services_by_name['SinksService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.sinks.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinks'
  _LISTSINKSREQUEST._options = None
  _LISTSINKSREQUEST._serialized_options = b'\030\001'
  _LISTSINKSRESPONSE._options = None
  _LISTSINKSRESPONSE._serialized_options = b'\030\001'
  _DELETESINKREQUEST.fields_by_name['ref']._options = None
  _DELETESINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETESINKREQUEST._options = None
  _DELETESINKREQUEST._serialized_options = b'\030\001'
  _DELETESINKRESPONSE._options = None
  _DELETESINKRESPONSE._serialized_options = b'\030\001'
  _CREATESINKREQUEST.fields_by_name['sink']._options = None
  _CREATESINKREQUEST.fields_by_name['sink']._serialized_options = b'\340A\002'
  _CREATESINKREQUEST._options = None
  _CREATESINKREQUEST._serialized_options = b'\030\001'
  _CREATESINKRESPONSE._options = None
  _CREATESINKRESPONSE._serialized_options = b'\030\001'
  _GETSINKREQUEST.fields_by_name['ref']._options = None
  _GETSINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETSINKREQUEST._options = None
  _GETSINKREQUEST._serialized_options = b'\030\001'
  _GETSINKRESPONSE._options = None
  _GETSINKRESPONSE._serialized_options = b'\030\001'
  _SINKSSERVICE._options = None
  _SINKSSERVICE._serialized_options = b'\210\002\001'
  _LISTSINKSREQUEST._serialized_start=149
  _LISTSINKSREQUEST._serialized_end=239
  _LISTSINKSRESPONSE._serialized_start=241
  _LISTSINKSRESPONSE._serialized_end=318
  _DELETESINKREQUEST._serialized_start=320
  _DELETESINKREQUEST._serialized_end=418
  _DELETESINKRESPONSE._serialized_start=420
  _DELETESINKRESPONSE._serialized_end=444
  _CREATESINKREQUEST._serialized_start=446
  _CREATESINKREQUEST._serialized_end=552
  _CREATESINKRESPONSE._serialized_start=554
  _CREATESINKRESPONSE._serialized_end=627
  _GETSINKREQUEST._serialized_start=629
  _GETSINKREQUEST._serialized_end=753
  _GETSINKRESPONSE._serialized_start=755
  _GETSINKRESPONSE._serialized_end=834
  _SINKSSERVICE._serialized_start=837
  _SINKSSERVICE._serialized_end=1264
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_jobs/v1/batch_jobs_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/batch_jobs/v1/batch_jobs_v1.proto\x12\x1dstrmprivacy.api.batch_jobs.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"P\n\x12GetBatchJobRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\"T\n\x13GetBatchJobResponse\x12=\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x03\xe0\x41\x02\"G\n\x14ListBatchJobsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"R\n\x15ListBatchJobsResponse\x12\x39\n\nbatch_jobs\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.BatchJob\"V\n\x15\x43reateBatchJobRequest\x12=\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x03\xe0\x41\x02\"W\n\x16\x43reateBatchJobResponse\x12=\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x03\xe0\x41\x02\"S\n\x15\x44\x65leteBatchJobRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\"\x18\n\x16\x44\x65leteBatchJobResponse\"\xa2\x01\n\x1aUpdateBatchJobStateRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\x12H\n\x0f\x62\x61tch_job_state\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x02\"\x1d\n\x1bUpdateBatchJobStateResponse2\x91\x05\n\x10\x42\x61tchJobsService\x12t\n\x0bGetBatchJob\x12\x31.strmprivacy.api.batch_jobs.v1.GetBatchJobRequest\x1a\x32.strmprivacy.api.batch_jobs.v1.GetBatchJobResponse\x12z\n\rListBatchJobs\x12\x33.strmprivacy.api.batch_jobs.v1.ListBatchJobsRequest\x1a\x34.strmprivacy.api.batch_jobs.v1.ListBatchJobsResponse\x12}\n\x0e\x43reateBatchJob\x12\x34.strmprivacy.api.batch_jobs.v1.CreateBatchJobRequest\x1a\x35.strmprivacy.api.batch_jobs.v1.CreateBatchJobResponse\x12}\n\x0e\x44\x65leteBatchJob\x12\x34.strmprivacy.api.batch_jobs.v1.DeleteBatchJobRequest\x1a\x35.strmprivacy.api.batch_jobs.v1.DeleteBatchJobResponse\x12\x8c\x01\n\x13UpdateBatchJobState\x12\x39.strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateRequest\x1a:.strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateResponseBo\n io.strmprivacy.api.batch_jobs.v1P\x01ZIgithub.com/strmprivacy/api-definitions-go/v2/api/batch_jobs/v1;batch_jobsb\x06proto3')



_GETBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobRequest']
_GETBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobResponse']
_LISTBATCHJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListBatchJobsRequest']
_LISTBATCHJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListBatchJobsResponse']
_CREATEBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['CreateBatchJobRequest']
_CREATEBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['CreateBatchJobResponse']
_DELETEBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['DeleteBatchJobRequest']
_DELETEBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBatchJobResponse']
_UPDATEBATCHJOBSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateBatchJobStateRequest']
_UPDATEBATCHJOBSTATERESPONSE = DESCRIPTOR.message_types_by_name['UpdateBatchJobStateResponse']
GetBatchJobRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.GetBatchJobRequest)
  })
_sym_db.RegisterMessage(GetBatchJobRequest)

GetBatchJobResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.GetBatchJobResponse)
  })
_sym_db.RegisterMessage(GetBatchJobResponse)

ListBatchJobsRequest = _reflection.GeneratedProtocolMessageType('ListBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.ListBatchJobsRequest)
  })
_sym_db.RegisterMessage(ListBatchJobsRequest)

ListBatchJobsResponse = _reflection.GeneratedProtocolMessageType('ListBatchJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.ListBatchJobsResponse)
  })
_sym_db.RegisterMessage(ListBatchJobsResponse)

CreateBatchJobRequest = _reflection.GeneratedProtocolMessageType('CreateBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHJOBREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.CreateBatchJobRequest)
  })
_sym_db.RegisterMessage(CreateBatchJobRequest)

CreateBatchJobResponse = _reflection.GeneratedProtocolMessageType('CreateBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHJOBRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.CreateBatchJobResponse)
  })
_sym_db.RegisterMessage(CreateBatchJobResponse)

DeleteBatchJobRequest = _reflection.GeneratedProtocolMessageType('DeleteBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHJOBREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.DeleteBatchJobRequest)
  })
_sym_db.RegisterMessage(DeleteBatchJobRequest)

DeleteBatchJobResponse = _reflection.GeneratedProtocolMessageType('DeleteBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHJOBRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.DeleteBatchJobResponse)
  })
_sym_db.RegisterMessage(DeleteBatchJobResponse)

UpdateBatchJobStateRequest = _reflection.GeneratedProtocolMessageType('UpdateBatchJobStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBATCHJOBSTATEREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateRequest)
  })
_sym_db.RegisterMessage(UpdateBatchJobStateRequest)

UpdateBatchJobStateResponse = _reflection.GeneratedProtocolMessageType('UpdateBatchJobStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBATCHJOBSTATERESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateResponse)
  })
_sym_db.RegisterMessage(UpdateBatchJobStateResponse)

_BATCHJOBSSERVICE = DESCRIPTOR.services_by_name['BatchJobsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.batch_jobs.v1P\001ZIgithub.com/strmprivacy/api-definitions-go/v2/api/batch_jobs/v1;batch_jobs'
  _GETBATCHJOBREQUEST.fields_by_name['ref']._options = None
  _GETBATCHJOBREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETBATCHJOBRESPONSE.fields_by_name['batch_job']._options = None
  _GETBATCHJOBRESPONSE.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBRESPONSE.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBRESPONSE.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _DELETEBATCHJOBREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHJOBREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['ref']._options = None
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['batch_job_state']._options = None
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['batch_job_state']._serialized_options = b'\340A\002'
  _GETBATCHJOBREQUEST._serialized_start=164
  _GETBATCHJOBREQUEST._serialized_end=244
  _GETBATCHJOBRESPONSE._serialized_start=246
  _GETBATCHJOBRESPONSE._serialized_end=330
  _LISTBATCHJOBSREQUEST._serialized_start=332
  _LISTBATCHJOBSREQUEST._serialized_end=403
  _LISTBATCHJOBSRESPONSE._serialized_start=405
  _LISTBATCHJOBSRESPONSE._serialized_end=487
  _CREATEBATCHJOBREQUEST._serialized_start=489
  _CREATEBATCHJOBREQUEST._serialized_end=575
  _CREATEBATCHJOBRESPONSE._serialized_start=577
  _CREATEBATCHJOBRESPONSE._serialized_end=664
  _DELETEBATCHJOBREQUEST._serialized_start=666
  _DELETEBATCHJOBREQUEST._serialized_end=749
  _DELETEBATCHJOBRESPONSE._serialized_start=751
  _DELETEBATCHJOBRESPONSE._serialized_end=775
  _UPDATEBATCHJOBSTATEREQUEST._serialized_start=778
  _UPDATEBATCHJOBSTATEREQUEST._serialized_end=940
  _UPDATEBATCHJOBSTATERESPONSE._serialized_start=942
  _UPDATEBATCHJOBSTATERESPONSE._serialized_end=971
  _BATCHJOBSSERVICE._serialized_start=974
  _BATCHJOBSSERVICE._serialized_end=1631
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMstrmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto\x12+strmprivacy.api.customer_entity_versions.v1\x1a\x1fgoogle/api/field_behavior.proto\"\x1e\n\x1cGetBatchExporterImageRequest\"W\n\x1dGetBatchExporterImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1cGetKafkaExporterImageRequest\"3\n\x1dGetKafkaExporterImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x1a\n\x18GetDecrypterImageRequest\"S\n\x19GetDecrypterImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1f\n\x1dGetBatchJobRunnerImageRequest\"X\n\x1eGetBatchJobRunnerImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x03\xe0\x41\x02\x32\xda\x05\n\x1d\x43ustomerEntityVersionsService\x12\xae\x01\n\x15GetBatchExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse\x12\xae\x01\n\x15GetKafkaExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse\x12\xa2\x01\n\x11GetDecrypterImage\x12\x45.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest\x1a\x46.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse\x12\xb1\x01\n\x16GetBatchJobRunnerImage\x12J.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest\x1aK.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponseB\x99\x01\n.io.strmprivacy.api.customer_entity_versions.v1P\x01Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versionsb\x06proto3')



_GETBATCHEXPORTERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetBatchExporterImageRequest']
_GETBATCHEXPORTERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetBatchExporterImageResponse']
_GETKAFKAEXPORTERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaExporterImageRequest']
_GETKAFKAEXPORTERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaExporterImageResponse']
_GETDECRYPTERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetDecrypterImageRequest']
_GETDECRYPTERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetDecrypterImageResponse']
_GETBATCHJOBRUNNERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobRunnerImageRequest']
_GETBATCHJOBRUNNERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobRunnerImageResponse']
GetBatchExporterImageRequest = _reflection.GeneratedProtocolMessageType('GetBatchExporterImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest)
  })
_sym_db.RegisterMessage(GetBatchExporterImageRequest)

GetBatchExporterImageResponse = _reflection.GeneratedProtocolMessageType('GetBatchExporterImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse)
  })
_sym_db.RegisterMessage(GetBatchExporterImageResponse)

GetKafkaExporterImageRequest = _reflection.GeneratedProtocolMessageType('GetKafkaExporterImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAEXPORTERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest)
  })
_sym_db.RegisterMessage(GetKafkaExporterImageRequest)

GetKafkaExporterImageResponse = _reflection.GeneratedProtocolMessageType('GetKafkaExporterImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAEXPORTERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse)
  })
_sym_db.RegisterMessage(GetKafkaExporterImageResponse)

GetDecrypterImageRequest = _reflection.GeneratedProtocolMessageType('GetDecrypterImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDECRYPTERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest)
  })
_sym_db.RegisterMessage(GetDecrypterImageRequest)

GetDecrypterImageResponse = _reflection.GeneratedProtocolMessageType('GetDecrypterImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDECRYPTERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse)
  })
_sym_db.RegisterMessage(GetDecrypterImageResponse)

GetBatchJobRunnerImageRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobRunnerImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBRUNNERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest)
  })
_sym_db.RegisterMessage(GetBatchJobRunnerImageRequest)

GetBatchJobRunnerImageResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobRunnerImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBRUNNERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponse)
  })
_sym_db.RegisterMessage(GetBatchJobRunnerImageResponse)

_CUSTOMERENTITYVERSIONSSERVICE = DESCRIPTOR.services_by_name['CustomerEntityVersionsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.strmprivacy.api.customer_entity_versions.v1P\001Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versions'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_start=159
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_end=189
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_start=191
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_end=278
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_start=280
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_end=310
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_start=312
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_end=363
  _GETDECRYPTERIMAGEREQUEST._serialized_start=365
  _GETDECRYPTERIMAGEREQUEST._serialized_end=391
  _GETDECRYPTERIMAGERESPONSE._serialized_start=393
  _GETDECRYPTERIMAGERESPONSE._serialized_end=476
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_start=478
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_end=509
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_start=511
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_end=599
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_start=602
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_end=1332
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_exporters/v1/kafka_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/kafka_exporters/v1/kafka_exporters_v1.proto\x12\"strmprivacy.api.kafka_exporters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"L\n\x19ListKafkaExportersRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x03\"a\n\x1aListKafkaExportersResponse\x12\x43\n\x0fkafka_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporter\"u\n\x1a\x44\x65leteKafkaExporterRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x03\xe0\x41\x02\x12\x16\n\trecursive\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02\"\x1d\n\x1b\x44\x65leteKafkaExporterResponse\"e\n\x1a\x43reateKafkaExporterRequest\x12G\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterB\x03\xe0\x41\x02\"a\n\x1b\x43reateKafkaExporterResponse\x12\x42\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporter\"Z\n\x17GetKafkaExporterRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x03\xe0\x41\x02\"^\n\x18GetKafkaExporterResponse\x12\x42\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporter2\xef\x04\n\x15KafkaExportersService\x12\x93\x01\n\x12ListKafkaExporters\x12=.strmprivacy.api.kafka_exporters.v1.ListKafkaExportersRequest\x1a>.strmprivacy.api.kafka_exporters.v1.ListKafkaExportersResponse\x12\x8d\x01\n\x10GetKafkaExporter\x12;.strmprivacy.api.kafka_exporters.v1.GetKafkaExporterRequest\x1a<.strmprivacy.api.kafka_exporters.v1.GetKafkaExporterResponse\x12\x96\x01\n\x13\x44\x65leteKafkaExporter\x12>.strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterRequest\x1a?.strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterResponse\x12\x96\x01\n\x13\x43reateKafkaExporter\x12>.strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterRequest\x1a?.strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterResponseB~\n%io.strmprivacy.api.kafka_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_exporters/v1;kafka_exportersb\x06proto3')



_LISTKAFKAEXPORTERSREQUEST = DESCRIPTOR.message_types_by_name['ListKafkaExportersRequest']
_LISTKAFKAEXPORTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListKafkaExportersResponse']
_DELETEKAFKAEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteKafkaExporterRequest']
_DELETEKAFKAEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteKafkaExporterResponse']
_CREATEKAFKAEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['CreateKafkaExporterRequest']
_CREATEKAFKAEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['CreateKafkaExporterResponse']
_GETKAFKAEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaExporterRequest']
_GETKAFKAEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaExporterResponse']
ListKafkaExportersRequest = _reflection.GeneratedProtocolMessageType('ListKafkaExportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKAEXPORTERSREQUEST,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.ListKafkaExportersRequest)
  })
_sym_db.RegisterMessage(ListKafkaExportersRequest)

ListKafkaExportersResponse = _reflection.GeneratedProtocolMessageType('ListKafkaExportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKAEXPORTERSRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.ListKafkaExportersResponse)
  })
_sym_db.RegisterMessage(ListKafkaExportersResponse)

DeleteKafkaExporterRequest = _reflection.GeneratedProtocolMessageType('DeleteKafkaExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKAEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterRequest)
  })
_sym_db.RegisterMessage(DeleteKafkaExporterRequest)

DeleteKafkaExporterResponse = _reflection.GeneratedProtocolMessageType('DeleteKafkaExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKAEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterResponse)
  })
_sym_db.RegisterMessage(DeleteKafkaExporterResponse)

CreateKafkaExporterRequest = _reflection.GeneratedProtocolMessageType('CreateKafkaExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKAEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterRequest)
  })
_sym_db.RegisterMessage(CreateKafkaExporterRequest)

CreateKafkaExporterResponse = _reflection.GeneratedProtocolMessageType('CreateKafkaExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKAEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterResponse)
  })
_sym_db.RegisterMessage(CreateKafkaExporterResponse)

GetKafkaExporterRequest = _reflection.GeneratedProtocolMessageType('GetKafkaExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.GetKafkaExporterRequest)
  })
_sym_db.RegisterMessage(GetKafkaExporterRequest)

GetKafkaExporterResponse = _reflection.GeneratedProtocolMessageType('GetKafkaExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_exporters.v1.GetKafkaExporterResponse)
  })
_sym_db.RegisterMessage(GetKafkaExporterResponse)

_KAFKAEXPORTERSSERVICE = DESCRIPTOR.services_by_name['KafkaExportersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.kafka_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_exporters/v1;kafka_exporters'
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['recursive']._options = None
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['recursive']._serialized_options = b'\340A\002'
  _CREATEKAFKAEXPORTERREQUEST.fields_by_name['kafka_exporter']._options = None
  _CREATEKAFKAEXPORTERREQUEST.fields_by_name['kafka_exporter']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTKAFKAEXPORTERSREQUEST._serialized_start=179
  _LISTKAFKAEXPORTERSREQUEST._serialized_end=255
  _LISTKAFKAEXPORTERSRESPONSE._serialized_start=257
  _LISTKAFKAEXPORTERSRESPONSE._serialized_end=354
  _DELETEKAFKAEXPORTERREQUEST._serialized_start=356
  _DELETEKAFKAEXPORTERREQUEST._serialized_end=473
  _DELETEKAFKAEXPORTERRESPONSE._serialized_start=475
  _DELETEKAFKAEXPORTERRESPONSE._serialized_end=504
  _CREATEKAFKAEXPORTERREQUEST._serialized_start=506
  _CREATEKAFKAEXPORTERREQUEST._serialized_end=607
  _CREATEKAFKAEXPORTERRESPONSE._serialized_start=609
  _CREATEKAFKAEXPORTERRESPONSE._serialized_end=706
  _GETKAFKAEXPORTERREQUEST._serialized_start=708
  _GETKAFKAEXPORTERREQUEST._serialized_end=798
  _GETKAFKAEXPORTERRESPONSE._serialized_start=800
  _GETKAFKAEXPORTERRESPONSE._serialized_end=894
  _KAFKAEXPORTERSSERVICE._serialized_start=897
  _KAFKAEXPORTERSSERVICE._serialized_end=1520
# @@protoc_insertion_point(module_scope)
